@@ -1,5 +1,5 @@
 from functools import wraps
-from flask.ext.restful import unpack
+from flask_restful import unpack
 from flask_presst.api import PresstApi
 from flask_presst.resources import PresstResource, ModelResource, PolymorphicModelResource
 from flask_presst.nesting import Relationship, resource_method
@@ -19,6 +19,9 @@ __all__ = (
     'PresstArgument',
     'Reference',
     'marshal_with_field',
+
+    'fields',
+    'signals',
 )
 
 
