@@ -1,8 +1,8 @@
 import datetime
 from flask import request, current_app, _request_ctx_stack
-from flask.ext.restful import reqparse, Resource, abort, marshal
-from flask.ext.restful.fields import Boolean, String, Integer, DateTime, Raw
-from flask.ext.sqlalchemy import BaseQuery, Pagination, get_state
+from flask_restful import reqparse, Resource, abort, marshal
+from flask_restful.fields import Boolean, String, Integer, DateTime, Raw
+from flask_sqlalchemy import BaseQuery, Pagination, get_state
 from flask.views import MethodViewType
 from sqlalchemy.dialects import postgres
 from sqlalchemy.orm import class_mapper
@@ -79,7 +79,7 @@ class PresstResource(six.with_metaclass(PresstResourceMeta, Resource)):
                            never be marshalled [#f1]_. *Default: 'id'*
     required_fields        A list of fields that must be given in `POST` requests.
     read_only_fields       A list of fields that are returned by the resource but are ignored in `POST`
-                           and `PATCH` requests.
+                           and `PATCH` requests. Useful for e.g. timestamps.
     =====================  ==============================================================================
 
     .. rubric:: Footnotes
